Graph Clustering
=================

**Correlated clustering on complex networks:**

.. literalinclude:: ../examples/correlated_louvain_example.py
   :language: python
   :caption: Example correlated Louvain clustering workflow

.. literalinclude:: ../examples/correlated_hybrid_louvain.py
   :language: python
   :caption: Example correlated hybrid Louvain clustering workflow
